@@ -10,6 +10,9 @@ use Class::XSAccessor
         (map { $_ => $_ } (qw(
         base
         basename
+        is_dir
+        is_file
+        is_link
         path
         dir_components
         stat_ret
@@ -29,17 +32,12 @@ sub new
     return $self;
 }
 
-sub is_dir
-{
-    return S_ISDIR(shift->stat_ret->[2]);
-}
-
 sub full_components
 {
     my $self = shift;
 
     return
-    [ 
+    [
         @{$self->dir_components()},
         ($self->is_dir() ? () : $self->basename()),
     ];
@@ -75,9 +73,18 @@ is equivalent to C<< $ffo->next() >> .
 
 Returns true if the result refers to a directory.
 
+=head2 $result->is_file()
+
+Returns true if the result refers to a plain file (equivalent to the Perl
+C<-f> operator).
+
+=head2 $result->is_link()
+
+Returns true if the result is a symbolic link.
+
 =head2 $result->dir_components()
 
-The components of the directory part of the path starting from base() 
+The components of the directory part of the path starting from base()
 (also the full path if the result is a directory) as an array reference.
 
 =head2 $result->basename()
@@ -93,7 +100,7 @@ a file.
 =head2 $result->stat_ret()
 
 The return value of L<perlfunc/stat> for the result, placed
-inside an array reference. This is calculated by L<File::Find::Object> and 
+inside an array reference. This is calculated by L<File::Find::Object> and
 kept here for convenience and for internal use.
 
 =head1 SEE ALSO
@@ -104,10 +111,10 @@ L<File::Find::Object>
 
 Copyright (C) 2005, 2006 by Olivier Thauvin
 
-This package is free software; you can redistribute it and/or modify it under 
+This package is free software; you can redistribute it and/or modify it under
 the following terms:
 
-1. The GNU General Public License Version 2.0 - 
+1. The GNU General Public License Version 2.0 -
 http://www.opensource.org/licenses/gpl-license.php
 
 2. The Artistic License Version 2.0 -
